
Download
========

.. include:: ../../README.rst
    :start-after: ``pyunicorn`` is `BSD-licensed <LICENSE.txt>`_ (3 clause).
    :end-before: Test suite

.. include:: ../../README.rst
    :start-after: graphs.
    :end-before: License
